/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef _AIR_MEDIAHUB_MEDIADATA_H__
#define _AIR_MEDIAHUB_MEDIADATA_H__

#include <stdbool.h>

struct mediadata;

enum media_type {
	E_MEDIA_PHOTO = 0,
	E_MEDIA_VIDEO,
	E_MEDIA_SOUND,
	E_MEDIA_MUSIC,
	E_MEDIA_OTHER,
	E_MEDIA_MAX
};

enum source_type {
	E_SOURCE_INTERNAL = 0,
	E_SOURCE_EXTERNAL,
	E_SOURCE_ALL,
	E_SOURCE_MAX
};

enum sort_type {
	E_SORT_DATE = 0,
	E_SORT_NAME,
	E_SORT_MAX
};

enum list_type {
	E_LIST_DATE = 0,
	E_LIST_NAME,
	E_LIST_GENRE,
	E_LIST_MAX
};

struct group_info {
	char *name;
	Eina_List *list;
	void *data;
};

struct mediadata *mediadata_create(const char *media_type,
			int source_type, int sort_type);
void mediadata_destroy(struct mediadata *md);

Eina_List *mediadata_get_medialist(struct mediadata *md);
int mediadata_get_media_count(struct mediadata *md, int media_type);

Eina_List *mediadata_get_list(struct mediadata *md, int list_type);
void mediadata_free_list(Eina_List *list);

#endif /* _AIR_MEDIAHUB_MEDIADATA_H__ */
