/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __AIR_MEDIAHUB_DEFINE_H__
#define __AIR_MEDIAHUB_DEFINE_H__

/* views */
#include "view/base.h"
#include "view/viewer.h"
#include "view/mplayer.h"
#include "view/action_menu.h"
#include "view/zoom.h"

/* layouts */
#include "layout/movie.h"
#include "layout/gallery.h"
#include "layout/music.h"

/* defines */
#define STYLE_INVISIBLE "invisible"

#define FONT_REGULAR "TizenSans"
#define FONT_LIGHT "TizenSans:style=Light"
#define FONT_BOLD "TizenSans:style=Bold"

#define COLOR_BASE_BG 247 247 247 255
#define COLOR_TEXT_TITLE 51 51 51 255
#define COLOR_TEXT_MENU 104 104 104 255
#define COLOR_TEXT_INDEX 77 77 77 255
#define COLOR_TEXT_NORMAL 87 87 87 255
#define COLOR_TEXT_INFO 153 153 153 255
#define COLOR_TEXT_FOCUS 255 255 255 255
#define COLOR_TEXT_FOCUS_0 255 255 255 0
#define COLOR_TEXT_SELECTED 64 136 211 255
#define COLOR_TEXT_DISABLED 87 87 87 128
#define COLOR_TEXT_BG 113 128 147 255
#define COLOR_ITEM_BG 255 255 255 255
#define COLOR_ITEM_DEFAULT 119 169 202 255
#define COLOR_ITEM_FOCUS 0 119 246 255
#define COLOR_ITEM_FOCUS_0 0 119 246 0
#define COLOR_ITEM_SELECTED 64 136 211 255
#define COLOR_ITEM_BAR 190 190 190 255
#define COLOR_ITEM_BORDER 194 194 194 255
#define COLOR_ITEM_DIVIDER 224 224 224 255
#define COLOR_LIST_BG 244 244 244 255
#define COLOR_POPUP_BORDER 154 154 154 255
#define COLOR_NO_CONTENT_BG 229 229 229 255

#define SHOW_VIEW_INTERVAL 0.1

/* part */
#define PART_ELM_TEXT_TITLE "elm.text.title"
#define PART_ELM_TEXT_TITLE2 "elm.text.title2"
#define PART_ELM_TEXT_ARTIST "elm.text.artist"
#define PART_ELM_TEXT_ALBUM "elm.text.album"
#define PART_ELM_TEXT_PLAYTIME "elm.text.playtime"
#define PART_ELM_TEXT_COUNT "elm.text.count"
#define PART_ELM_SWALLOW_THUMBNAIL "elm.swallow.thumbnail"
#define PART_ELM_SWALLOW_VIDEO "elm.swallow.video"
#define PART_ELM_SWALLOW_FAVORITE "elm.swallow.favorite"
#define PART_ELM_SWALLOW_BG "elm.swallow.bg"
#define PART_ELM_SWALLOW_TEXTBG "elm.swallow.textbg"

/* signal */
#define SIG_BTN_CLICKED "btn,clicked"
#define SIG_BTN_SELECTED "btn,selected"
#define SIG_BTN_UNSELECTED "btn,unselected"
#define SIG_ITEM_SELECTED "item,selected"
#define SIG_ITEM_UNSELECTED "item,unselected"
#define SIG_ITEM_TOGGLED "item,toggled"
#define SIG_ELM_HIDE "elm,state,hide"
#define SIG_ELM_DISABLED "elm,state,disabled"
#define SIG_ELM_FOCUS "elm,action,focus"
#define SIG_ELM_UNFOCUS "elm,action,unfocus"
#define SIG_ELM_UNFOCUSED "elm,state,unfocused"
#define SIG_SOURCE_EDC "edc"
#define SIG_SOURCE_ELM "elm"
#define SIG_SOURCE_SRC "src"
#define SIG_SHOW_VIEW "show,view"
#define SIG_HIDE_VIEW "hide,view"
#define SIG_HIDE_DONE "hide,done"
#define SIG_HIDE_SET "hide,set"
#define SIG_DISMISSED "dismissed"
#define SIG_TIMEOUT "timeout"
#define SIG_SCROLL "scroll"

/* style */
#define STYLE_TOAST "base_toast"

/* transition */
#define TRANSITION_FOCUS DECELERATE 0.20
#define TRANSITION_CLICK DECELERATE 0
#define TRANSITION_SHOW_BAR LINEAR 0.20
#define TRANSITION_SHOW_ICON LINEAR 0.35
#define TRANSITION_SHOW_VIEW SINUSOIDAL 0.20
#define TRANSITION_SHOW_BASE_VIEW DECELERATE 0.01
#define TRANSITION_SHOW_MENU SINUSOIDAL 0.45
#define TRANSITION_HIDE_MENU DECELERATE 0.30

#endif /* __AIR_MEDIAHUB_DEFINE_H__ */
